@@ -61,6 +61,8 @@ class JsonParser(DataParser):
             dict['userId'] = message.login_user_id
         if hasattr(message, 'attributes') and message.attributes is not None:
             dict['attributes'] = message.attributes
+        if hasattr(message, 'send_time') and message.send_time is not None:
+            dict['sendTime'] = message.send_time
 
         # item message
         if hasattr(message, 'key') and message.key is not None:
@@ -75,6 +77,6 @@ class JsonParser(DataParser):
         if hasattr(message, 'product_id'): dict['projectKey'] = message.product_id
 
         dict['sdkVersion'] = VERSION
-        dict['sdkType'] = 'python'
+        dict['platform'] = 'python'
 
         return self.json_dumps(dict)
